@@ -18,8 +18,16 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkft.endpoint import endpoint_data
 
 class FtDynamicAddressHsfRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Ft', '2018-07-13', 'FtDynamicAddressHsf')
\ No newline at end of file
+		RpcRequest.__init__(self, 'Ft', '2018-07-13', 'FtDynamicAddressHsf')
+		self.set_method('POST')
+
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
