@@ -18,14 +18,21 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkft.endpoint import endpoint_data
 
 class FtEagleEyeRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Ft', '2018-07-13', 'FtEagleEye')
+		self.set_method('POST')
 
-	def get_Name(self):
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
+	def get_Name(self): # String
 		return self.get_query_params().get('Name')
 
-	def set_Name(self,Name):
-		self.add_query_param('Name',Name)
\ No newline at end of file
+	def set_Name(self, Name):  # String
+		self.add_query_param('Name', Name)
